@@ -1,4 +1,4 @@
-from testWheel.__init__ import *
+from atttest.__init__ import *
 
 def func_test():
     print("Successfully Imported test.py file")
